%1-30-2008 Raj
%This file plots effect of variations in benefits, annuity payment, and wages on search intensity.
%Initial asset levels: -$1,000, $13,000

%psi(s) = theta*[s^(1+sigma)]/(1+sigma)
%psi'(s)=theta*s^sigma
%delta=0, r=0
%NOTE: sigma here is referred to as KAPPA in the text to avoid confusion with average frac employed.

clear all

%theta = 5
%sigma = 0.1
%gamma = 1.75

theta = 5
sigma = 0.1

gamma = 1.75

w=340
T=500
B=26

L=-1000
gridsize = 400
a=0;
tau=0.01*0.5*w

G=0
G_T=T

tic

%Step 0: Evaluate fit of model to data at replacement rate of 50% and A0=100
%need to be careful that asset increment and ben increment are similar, and compare to analytical results generated by opt_polfn

A0=100
b = 0.5*w;
rr_inc_der = .02

%baseline
[D_star, D_comp_star, S_0_star, J_0_star, rho_star] = opt_search_polfn_crra(A0,L,G,G_T,w,a,b,tau,T,B,gridsize,theta,sigma,gamma);

%calculate ds/da
[D_ainc, D_comp_ainc, S_0_ainc, J_0_ainc, rho_ainc] = opt_search_polfn_crra(A0,L,G,G_T,w,a+rr_inc_der*w,b,tau,T,B,gridsize,theta,sigma,gamma);
ds_da = (S_0_ainc-S_0_star)/(rr_inc_der*w);

%calculate ds/dA
[D_Ainc, D_comp_Ainc, S_0_Ainc, J_0_Ainc, rho_Ainc] = opt_search_polfn_crra(A0+rr_inc_der*w,L,G,G_T,w,a,b,tau,T,B,gridsize,theta,sigma,gamma);
ds_dA = (S_0_Ainc-S_0_star)/(rr_inc_der*w);

%calculate ds/db and e_db (partial der, so this is an approximation)
[D_binc, D_comp_binc, S_0_binc, J_0_binc] = opt_search_polfn_crra(A0,L,G,G_T,w,a,b+rr_inc_der*w,tau,T,B,gridsize,theta,sigma,gamma);
ds_db = (S_0_binc-S_0_star)/(rr_inc_der*w);
e_db = (log(D_binc)-log(D_star))/(log(b+rr_inc_der*w)-log(b));

sig = (T-D_star)/T;

liq_mh_a = -ds_da/(ds_da-ds_db);
liq_mh_A = -B*ds_dA/(B*ds_dA-ds_db);

disp('Key moments to match data: D_star, e_db, liq_mh_A')
key_moments = [D_comp_star e_db liq_mh_A]

%Specify asset groups for figures
A0=[-1000 13000]

%1 Plot effect of UI benefits on search intensity by asset group

rr_inc = .03
reprate = [.05:.015:.2 .21:.03:.96]
b=reprate*w;
clear s_0 J_0 rho D

for i = 1:length(A0) 
    for j = 1:length(b)
    disp(['Current asset level and reprate: ' num2str(A0(i)) ',' num2str(reprate(j))])        
    disp(reprate(j))
    [D_star, D_comp_star, S_0_star, J_0_star, rho_star, liq_mh_a_star liq_mh_A_star] = opt_search_polfn_crra(A0(i),L,G,G_T,w,a,b(j),tau,T,B,gridsize,theta,sigma,gamma);
    D(j,i) = D_star;
    s_0(j,i) = S_0_star;
    J_0(j,i) = J_0_star;
    rho(j,i) = rho_star;
    liq_mh_a(j,i) = liq_mh_a_star;
    liq_mh_A(j,i) = liq_mh_A_star;
    end
end

ds_db = (s_0(2:length(b),:) - s_0(1:length(b)-1,:))/(rr_inc*w);

temp_s = s_0(1:length(b)-1,:);
temp_b_vec = b(1:length(b)-1);
temp_b = temp_b_vec(ones(1,length(A0)),:);
temp_b = temp_b';
e_sb = ds_db.*temp_b./temp_s;

data_b = [reprate' s_0]

%2 Plot effect of annuity increase on search intensity by asset group
b_fixed = 0;
clear s_0 J_0 rho D

for i = 1:length(A0) 
    for j = 1:length(b)
    disp(['Current asset level and sevpay: ' num2str(A0(i)) ',' num2str(reprate(j))])
    [D_star, D_comp_star, S_0_star, J_0_star, rho_star] = opt_search_polfn_crra(A0(i),L,G,G_T,w,b(j),b_fixed,tau,T,B,gridsize,theta,sigma,gamma);
    D(j,i) = D_star;
    s_0(j,i) = S_0_star;
    J_0(j,i) = J_0_star;
    rho(j,i) = rho_star;
    end
end

ds_da = (s_0(2:length(b),:) - s_0(1:length(b)-1,:))/(rr_inc*w);
data_s = [reprate' s_0]

%3 Construct Data

save fig1_data_b_final data_b
save fig1_data_a_final data_s

toc
